@@ -1,14 +1,4 @@
-use MooseX::Declare;
-
-role VANAMBURG::SEMPROG::InferenceRule{
-
-    requires qw/getqueries maketriples/;
-
-}
-
-
-__END__
-
+package VANAMBURG::SEMPROG::InferenceRule;
 
 =head1 VANAMBURG::SEMPROG::InferenceRule
 
@@ -29,3 +19,9 @@ maketriples
 
 =cut
 
+use Moose::Role;
+
+requires qw/getqueries maketriples/;
+
+1;
+
